# YAMS
Yet Another Motionsense Service utility

## Quickstart

- `pip install -U yams-util`
- `python -m yams`


## Development guide

- Clone the repository
    - `git clone https://github.com/SenSE-Lab-OSU/YAMS.git`
- Install dependencies 
    - `pip install gradio bleak`
- Launch the application
    - `python app.py`
- Visit http://127.0.0.1:7860 (by default, check on-screen prompt)


## Roadmap

- [x] Device data transfer
- [ ] Device data post processing
    - [ ] format conversion
    - [ ] visualization
- [ ] simple data collection utilities